#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['advent_of_code_ocr']

package_data = \
{'': ['*']}

extras_require = \
{'test': ['numpy', 'pytest']}

setup(name='advent-of-code-ocr',
      version='1.0.0',
      description='Convert Advent of Code ASCII art',
      author=None,
      author_email='Ben Soyka <bensoyka@icloud.com>',
      url=None,
      packages=packages,
      package_data=package_data,
      extras_require=extras_require,
      python_requires='~=3.7',
     )
